@@ -442,101 +442,40 @@ class Customer(object):
 
         # ====================================================================
         #  TODO: fetch CDRs directly from BI database
-        url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
-            eng=CONFIG['BI']['engine'],
-            user=CONFIG['BI']['user'],
-            password=CONFIG['BI']['password'],
-            host=CONFIG['BI']['host'],
-            port=CONFIG['BI']['port'],
-            name=CONFIG['BI']['table_name']
-        )
-        sql = (
-            "SELECT * FROM all_cdr WHERE "
-            "clientname='{}' AND "
-            "sessiontime >= '{}'::date"
-            .format(self.name, last_date)
-        )
-        try:
-            with records.Database(url) as db:
-                rows = db.query(sql)
-                cdrs_raw = rows.as_dict()
-            LOGS.logger.info(
-                "{} CRDs fetched from BI database for customer {}"
-                .format(len(cdrs_raw), self.name)
-            )
-        except Exception as e:
-            LOGS.logger.error(
-                "Unable to fetch customer {} CDRs: {}"
-                .format(self.name, str(e))
-            )
-            core.send_error_report("CDRs synchronization", str(e))
-            # we don't raise an exception, we assume customer has not used
-            # their Internet
-
-        cdrs = sorted(
-            cdrs_raw or [],
-            key=lambda x: datetime.strptime(
-                x['sessiontime'],
-                '%Y-%m-%dT%H:%M:%S'
-            )
-        )
-        # ====================================================================
-
-        # =================== fetching CRDs via Aiguiller ====================
-        # import time
-        # url = core.database_url(**FUPDB_CREDENTIALS)
+        # url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
+        #     eng=CONFIG['BI']['engine'],
+        #     user=CONFIG['BI']['user'],
+        #     password=CONFIG['BI']['password'],
+        #     host=CONFIG['BI']['host'],
+        #     port=CONFIG['BI']['port'],
+        #     name=CONFIG['BI']['table_name']
+        # )
+        # date = last_date + " 00:00:00"
+        # sql = (
+        #     "SELECT * FROM all_cdr WHERE "
+        #     "clientname='{}' AND "
+        #     "sessiontime >= '{}'::date"
+        #     .format(self.name, last_date)
+        # )
+        # try:
+        #     with records.Database(url) as db:
+        #         rows = db.query(sql)
+        #         cdrs_raw = rows.as_dict()
+        #     LOGS.logger.info(
+        #         "{} CRDs fetched from BI database for customer {}"
+        #         .format(len(cdrs_raw), self.name)
+        #     )
+        # except Exception as e:
+        #     LOGS.logger.error(
+        #         "Unable to fetch customer {} CDRs: {}"
+        #         .format(self.name, str(e))
+        #     )
+        #     core.send_error_report("CDRs synchronization", str(e))
+        #     # we don't raise an exception, we assume customer has not used
+        #     # their Internet
         #
-        # OK = False
-        # for i in range(3):
-        #     if OK:
-        #         break
-        #     try:
-        #         LOGS.logger.info(
-        #             "[customer {}] Fetching {} CDRs try {}/3"
-        #             .format(self.name, last_date, i+1)
-        #         )
-        #         response = requests.get(
-        #             CONFIG['AIGUILLIER']['url_v2'] + "/consommation",
-        #             auth=(
-        #                 CONFIG['AIGUILLIER']['username'],
-        #                 CONFIG['AIGUILLIER']['password']
-        #             ),
-        #             params={"client": self.name, "depuis_date": last_date}
-        #         )
-        #         infos = response.json()
-        #         LOGS.logger.info(
-        #             '[customer {}] CDRs count fetched from Aiguiller: {}'
-        #             .format(self.name, response)
-        #         )
-        #         if infos['status']:
-        #             OK = True
-        #     except requests.exceptions.Timeout:
-        #         LOGS.logger.info("essai TimeoutError {} de {}".format(
-        #             i,
-        #             self.name
-        #         ))
-        #         time.sleep(60)
-        #         continue
-        #     except ValueError:
-        #         LOGS.logger.info("essai ValueError {} de {}".format(
-        #             i,
-        #             self.name
-        #         ))
-        #         time.sleep(60)
-        #         continue
-        #     except Exception as e:
-        #         LOGS.logger.error(
-        #             "Unable to fetch customer {} CDRs: {}"
-        #             .format(self.name, str(e))
-        #         )
-        #         core.send_error_report("CDRs synchronization", str(e))
-        #         # we don't raise an exception, we assume customer has not used
-        #         # their Internet
-        #
-        # if type(infos) is str:
-        #     infos = json.loads(infos)
         # cdrs = sorted(
-        #     infos.get('cdr', []),
+        #     cdrs_raw or [],
         #     key=lambda x: datetime.strptime(
         #         x['sessiontime'],
         #         '%Y-%m-%dT%H:%M:%S'
@@ -544,6 +483,68 @@ class Customer(object):
         # )
         # ====================================================================
 
+        # =================== fetching CRDs via Aiguiller ====================
+        import time
+        url = core.database_url(**FUPDB_CREDENTIALS)
+
+        OK = False
+        for i in range(3):
+            if OK:
+                break
+            try:
+                LOGS.logger.info(
+                    "[customer {}] Fetching {} CDRs try {}/3"
+                    .format(self.name, last_date, i+1)
+                )
+                response = requests.get(
+                    CONFIG['AIGUILLIER']['url_v2'] + "/consommation",
+                    auth=(
+                        CONFIG['AIGUILLIER']['username'],
+                        CONFIG['AIGUILLIER']['password']
+                    ),
+                    params={"client": self.name, "depuis_date": last_date}
+                )
+                infos = response.json()
+                LOGS.logger.info(
+                    '[customer {}] CDRs count fetched from Aiguiller: {}'
+                    .format(self.name, response)
+                )
+                if infos['status']:
+                    OK = True
+            except requests.exceptions.Timeout:
+                LOGS.logger.info("essai TimeoutError {} de {}".format(
+                    i,
+                    self.name
+                ))
+                time.sleep(60)
+                continue
+            except ValueError:
+                LOGS.logger.info("essai ValueError {} de {}".format(
+                    i,
+                    self.name
+                ))
+                time.sleep(60)
+                continue
+            except Exception as e:
+                LOGS.logger.error(
+                    "Unable to fetch customer {} CDRs: {}"
+                    .format(self.name, str(e))
+                )
+                core.send_error_report("CDRs synchronization", str(e))
+                # we don't raise an exception, we assume customer has not used
+                # their Internet
+
+        if type(infos) is str:
+            infos = json.loads(infos)
+        cdrs = sorted(
+            infos.get('cdr', []),
+            key=lambda x: datetime.strptime(
+                x['sessiontime'],
+                '%Y-%m-%dT%H:%M:%S'
+            )
+        )
+        # ====================================================================
+
         cdrs = groupby(
             cdrs,
             key=lambda x: datetime.strptime(
